@@ -4,40 +4,40 @@
 #'
 #' @param x A price index, as made by, e.g., [elemental_index()].
 #' @param stringsAsFactors See [as.data.frame()].
-#' @param ... Further arguments passed to or used by methods.
+#' @param ... Not currently used.
 #'
 #' @returns
 #' `as.data.frame()` returns a data frame with three columns: `period`, `level`,
 #' and `value`.
 #'
 #' `as.matrix()` returns a matrix with a row for each level and a column
-#' for each period.
+#' for each time period.
 #'
 #' @seealso
 #' [as_index()] to coerce a matrix/data frame of index values into an index
 #' object.
 #'
 #' @examples
-#' prices <- data.frame(
-#'   rel = 1:8,
-#'   period = rep(1:2, each = 4),
-#'   ea = rep(letters[1:2], 4)
-#' )
+#' index <- as_index(matrix(1:6, 2))
 #'
-#' epr <- with(prices, elemental_index(rel, period, ea))
-#'
-#' as.data.frame(epr)
-#' as.matrix(epr)
+#' as.data.frame(index)
+#' as.matrix(index)
 #'
 #' @family index methods
 #' @export
 as.data.frame.piar_index <- function(x, ..., stringsAsFactors = FALSE) {
   value <- unlist(x$index, use.names = FALSE)
   period <- rep(x$time, each = length(x$levels))
-  data.frame(period,
-    level = x$levels, value,
-    stringsAsFactors = stringsAsFactors
-  )
+  if (stringsAsFactors) {
+    data.frame(period = factor(period, x$time),
+      level = factor(x$levels, x$levels), value
+    )
+  } else {
+    data.frame(period,
+      level = x$levels, value,
+      stringsAsFactors = FALSE
+    )
+  }
 }
 
 #' @rdname as.data.frame.piar_index
@@ -50,5 +50,5 @@ as.matrix.piar_index <- function(x, ...) {
 
 #' @export
 as.double.piar_index <- function(x, ...) {
-  as.double(as.matrix(x), ...)
+  as.double(as.matrix(x))
 }
